@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '0.71';
+$VERSION = '0.72';
 use base 'Exporter';
 
 our @EXPORT = qw/%builtin_types/;
@@ -270,12 +270,13 @@ my $hourFrag     = qr/ [01]\d | 2[0-3] /x;
 my $minuteFrag   = qr/ [0-5]\d /x;
 my $secondFrag   = qr/ [0-5]\d (?: \.\d+)? /x;
 my $endOfDayFrag = qr/24\:00\:00 (?: \.\d+)? /x;
-my $timezoneFrag = qr/Z | [+-] (0\d | 1[0-4]) \: $minuteFrag/x;
+my $timezoneFrag = qr/Z | [+-] (?: 0\d | 1[0-4] ) \: $minuteFrag/x;
 my $timeFrag     = qr/ (?: $hourFrag \: $minuteFrag \: $secondFrag )
                      | $endOfDayFrag
                      /x;
 
-my $date         = qr/^ $yearFrag \- $monthFrag \- $dayFrag $timezoneFrag? $/x;
+my $date = qr/^ $yearFrag \- $monthFrag \- $dayFrag (?: $timezoneFrag)? $/x;
+
 $builtin_types{date} =
  { parse   => \&_collapse
  , format  => sub { $_[0] =~ /\D/ ? $_[0] : strftime("%Y-%m-%d", gmtime $_[0])}
@@ -284,8 +285,18 @@ $builtin_types{date} =
  };
 
 
+my $time = qr /^ $timeFrag (?: $timezoneFrag )? $/x;
+
+$builtin_types{time} =
+ { parse   => \&_collapse
+ , format  => sub { $_[0] =~ /\D/ ? $_[0] : strftime("%T", gmtime $_[0])}
+ , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $time }
+ , example => '11:12:13'
+ };
+
+
 my $dateTime = qr/^ $yearFrag \- $monthFrag \- $dayFrag
-                    T $timeFrag $timezoneFrag? $/x;
+                    T $timeFrag (?: $timezoneFrag )? $/x;
 
 $builtin_types{dateTime} =
  { parse   => \&_collapse
@@ -296,7 +307,7 @@ $builtin_types{dateTime} =
  };
 
 
-my $gDay = qr/^ \- \- \- $dayFrag $timezoneFrag? $/x;
+my $gDay = qr/^ \- \- \- $dayFrag (?: $timezoneFrag )? $/x;
 $builtin_types{gDay} =
  { parse   => \&_collapse
  , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $gDay }
@@ -304,7 +315,7 @@ $builtin_types{gDay} =
  };
 
 
-my $gMonth = qr/^ \- \- $monthFrag $timezoneFrag? $/x;
+my $gMonth = qr/^ \- \- $monthFrag (?: $timezoneFrag )? $/x;
 $builtin_types{gMonth} =
  { parse   => \&_collapse
  , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $gMonth }
@@ -312,7 +323,7 @@ $builtin_types{gMonth} =
  };
 
 
-my $gMonthDay = qr/^ \- \- $monthFrag \- $dayFrag $timezoneFrag? /x;
+my $gMonthDay = qr/^ \- \- $monthFrag \- $dayFrag (?: $timezoneFrag )? /x;
 $builtin_types{gMonthDay} =
  { parse   => \&_collapse
  , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $gMonthDay }
@@ -320,7 +331,7 @@ $builtin_types{gMonthDay} =
  };
 
 
-my $gYear = qr/^ $yearFrag \- $monthFrag $timezoneFrag? $/x;
+my $gYear = qr/^ $yearFrag \- $monthFrag (?: $timezoneFrag )? $/x;
 $builtin_types{gYear} =
  { parse   => \&_collapse
  , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $gYear }
@@ -328,7 +339,7 @@ $builtin_types{gYear} =
  };
 
 
-my $gYearMonth = qr/^ $yearFrag \- $monthFrag $timezoneFrag? $/x;
+my $gYearMonth = qr/^ $yearFrag \- $monthFrag (?: $timezoneFrag )? $/x;
 $builtin_types{gYearMonth} =
  { parse   => \&_collapse
  , check   => sub { (my $val = $_[0]) =~ s/\s+//g; $val =~ $gYearMonth }
